CALLBACK_ACCES ="bearer exDOrTdJblja00UtBExNlRAOzwWX6LJVTKfkV78Rja00UtBExNlRAOzwWX6LJVTKfkV7"
HOST="https://myapiv1.upgroup-pay.com"
KEY_TOKEN="upgrouppay2020"
TYPE_PAYMENT=["OM","WAVE"]
WSHOST="wss://myapiv1.upgroup-pay.com"
DEBUG_HOST="http://localhost:8080"