"""payupweb URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path
from pay.views import home, payToUpWallet, om_callback, createCheckout, callback,test

urlpatterns = [
    path('samapay/', admin.site.urls),
    path('pay/<my_slug_key>/', home),
    path('pay/payToUp/<my_slug_key>/', payToUpWallet),
    path('payment/checkout', createCheckout),
    path('om/cb/', om_callback),
    path('notify/cb/', callback),
    # path('test', test),

    
]
